"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var ttl_exports = {};
__export(ttl_exports, {
  convertDuration: () => convertDuration,
  extractTTLConfig: () => extractTTLConfig
});
module.exports = __toCommonJS(ttl_exports);
var import_graphql = require("graphql");
var import_assert = require("@code-like-a-carpenter/assert");
var import_helpers = require("../helpers");
function convertDuration(duration) {
  const durationUnit = duration.slice(-1);
  const durationValue = duration.slice(0, -1);
  (0, import_assert.assert)(
    !Number.isNaN(durationValue),
    `Invalid ttl duration value: ${durationValue}`
  );
  switch (durationUnit) {
    case "s":
      return Number(durationValue) * 1e3;
    case "m":
      return Number(durationValue) * 1e3 * 60;
    case "h":
      return Number(durationValue) * 1e3 * 60 * 60;
    case "d":
      return Number(durationValue) * 1e3 * 60 * 60 * 24;
    default:
      (0, import_assert.fail)(`Invalid ttl duration: ${duration}. Unit must be one of s, m, h, d`);
  }
}
function extractTTLConfig(type) {
  const fields = type.astNode?.fields?.filter(
    (field) => field.directives?.map(({ name }) => name.value).includes("ttl")
  ) ?? [];
  if (fields.length === 0) {
    return void 0;
  }
  (0, import_assert.assert)(fields.length === 1, "Only one field can be marked with @ttl");
  const [astField] = fields;
  const fieldName = astField.name.value;
  const directive = (0, import_helpers.getDirective)("ttl", astField);
  const duration = (0, import_helpers.getOptionalArgStringValue)("duration", directive);
  if (!duration) {
    const field = type.getFields()[fieldName];
    return {
      argumentAllowed: true,
      argumentRequired: (0, import_graphql.isNonNullType)(field.type),
      fieldName
    };
  }
  const seconds = convertDuration(duration);
  return {
    argumentAllowed: !!(0, import_helpers.getOptionalArgBooleanValue)("overridable", directive),
    argumentRequired: false,
    duration: seconds,
    fieldName
  };
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  convertDuration,
  extractTTLConfig
});
