import { isNonNullType } from "graphql";
import { assert, fail } from "@code-like-a-carpenter/assert";
import {
  getDirective,
  getOptionalArgBooleanValue,
  getOptionalArgStringValue
} from "../helpers";
function convertDuration(duration) {
  const durationUnit = duration.slice(-1);
  const durationValue = duration.slice(0, -1);
  assert(
    !Number.isNaN(durationValue),
    `Invalid ttl duration value: ${durationValue}`
  );
  switch (durationUnit) {
    case "s":
      return Number(durationValue) * 1e3;
    case "m":
      return Number(durationValue) * 1e3 * 60;
    case "h":
      return Number(durationValue) * 1e3 * 60 * 60;
    case "d":
      return Number(durationValue) * 1e3 * 60 * 60 * 24;
    default:
      fail(`Invalid ttl duration: ${duration}. Unit must be one of s, m, h, d`);
  }
}
function extractTTLConfig(type) {
  const fields = type.astNode?.fields?.filter(
    (field) => field.directives?.map(({ name }) => name.value).includes("ttl")
  ) ?? [];
  if (fields.length === 0) {
    return void 0;
  }
  assert(fields.length === 1, "Only one field can be marked with @ttl");
  const [astField] = fields;
  const fieldName = astField.name.value;
  const directive = getDirective("ttl", astField);
  const duration = getOptionalArgStringValue("duration", directive);
  if (!duration) {
    const field = type.getFields()[fieldName];
    return {
      argumentAllowed: true,
      argumentRequired: isNonNullType(field.type),
      fieldName
    };
  }
  const seconds = convertDuration(duration);
  return {
    argumentAllowed: !!getOptionalArgBooleanValue("overridable", directive),
    argumentRequired: false,
    duration: seconds,
    fieldName
  };
}
export {
  convertDuration,
  extractTTLConfig
};
